==> autoscaling-1.60.0-sources.jar: software/amazon/awscdk/services/autoscaling/ScalingEvents.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * A list of ScalingEvents, you can use one of the predefined lists, such as ScalingEvents.ERRORS or create a custom group by instantiating a `NotificationTypes` object, e.g: `new NotificationTypes(`NotificationType.INSTANCE_LAUNCH`)`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.652Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.ScalingEvents")
public class ScalingEvents extends software.amazon.jsii.JsiiObject {

    protected ScalingEvents(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ScalingEvents(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "ALL", software.amazon.awscdk.services.autoscaling.ScalingEvents.class);
        ERRORS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "ERRORS", software.amazon.awscdk.services.autoscaling.ScalingEvents.class);
        LAUNCH_EVENTS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "LAUNCH_EVENTS", software.amazon.awscdk.services.autoscaling.ScalingEvents.class);
    }

    /**
     * @param types This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ScalingEvents(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.ScalingEvent... types) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.Arrays.<Object>stream(types).toArray(Object[]::new));
    }

    /**
     * All fleet scaling events.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents ALL;

    /**
     * Fleet scaling errors.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents ERRORS;

    /**
     * Fleet scaling launch events.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents LAUNCH_EVENTS;
}

==> autoscaling-1.93.0-sources.jar: software/amazon/awscdk/services/autoscaling/ScalingEvents.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * A list of ScalingEvents, you can use one of the predefined lists, such as ScalingEvents.ERRORS or create a custom group by instantiating a `NotificationTypes` object, e.g: `new NotificationTypes(`NotificationType.INSTANCE_LAUNCH`)`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:04.994Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.ScalingEvents")
public class ScalingEvents extends software.amazon.jsii.JsiiObject {

    protected ScalingEvents(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ScalingEvents(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "ALL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.ScalingEvents.class));
        ERRORS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "ERRORS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.ScalingEvents.class));
        LAUNCH_EVENTS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.autoscaling.ScalingEvents.class, "LAUNCH_EVENTS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.ScalingEvents.class));
    }

    /**
     * @param types This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ScalingEvents(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.ScalingEvent... types) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.Arrays.<Object>stream(types).toArray(Object[]::new));
    }

    /**
     * All fleet scaling events.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents ALL;

    /**
     * Fleet scaling errors.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents ERRORS;

    /**
     * Fleet scaling launch events.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.autoscaling.ScalingEvents LAUNCH_EVENTS;
}
